@@ -48,6 +48,7 @@
 #endif
 #include "cardinfo.h"
 #include "tasks.h"
+#include "sound/sound.h"
 
 #include <gpe/init.h>
 #include <gpe/picturebutton.h>
@@ -113,6 +114,8 @@ struct Applet applets[]=
 		"Serial" ,"serial","Serial Port Configuration",PREFIX "/share/pixmaps/gpe-config-serial.png"},
     { &Cardinfo_Build_Objects, &Cardinfo_Free_Objects, &Unimplemented_Save, &Cardinfo_Restore ,
 		"Cardinfo" ,"cardinfo","PC/CF Card Info and Config",PREFIX "/share/pixmaps/gpe-config-cardinfo.png"},
+    { &Sound_Build_Objects, &Sound_Free_Objects, &Sound_Save, &Sound_Restore , 
+		"Sound" ,"sound","Sound Setup",PREFIX "/share/pixmaps/gpe-config-sound.png"},
 #ifdef PACKAGETOOL		
     { &Packages_Build_Objects, &Packages_Free_Objects, &Unimplemented_Save, &Packages_Restore ,
 		"Packages" ,"packages","Add and Remove packages",PREFIX "/share/pixmaps/gpe-config-packages.png"},
@@ -120,7 +123,9 @@ struct Applet applets[]=
 		"Keyboard" ,"keyboard", "External Keyboard Setup",PREFIX "/share/pixmaps/gpe-config-keyboard.png"},
 #endif		
     { &Unimplemented_Build_Objects, &Unimplemented_Free_Objects, &Unimplemented_Save, &Unimplemented_Restore ,
-		"Task nameserver" ,"task_nameserver","Task for changing nameserver", NULL}
+		"Task nameserver" ,"task_nameserver","Task for changing nameserver", PREFIX "/share/pixmaps/gpe-config-admin.png"},
+    { &Unimplemented_Build_Objects, &Unimplemented_Free_Objects, &Unimplemented_Save, &Unimplemented_Restore ,
+		"Task sound" ,"task_sound","Command line task saving/restoring sound settings.", PREFIX "/share/pixmaps/gpe-config-admin.png"}
   };
   
 struct gpe_icon my_icons[] = {
@@ -138,6 +143,7 @@ struct gpe_icon my_icons[] = {
   { NULL, NULL }
 };
 
+
 #define count_icons 11
 
 int applets_nb = sizeof(applets) / sizeof(struct Applet);
@@ -312,6 +318,15 @@ void main_one(int argc, char **argv,int applet)
 	  {
 		  user_only_setup = TRUE;
 	  }
+	  if (!strcmp(argv[1],"task_sound"))
+	  {
+		  handled = TRUE;
+		  if (argc == 3)
+			  task_sound(argv[2]);
+		  else
+			  fprintf(stderr,_("'task_sound' needs (s)ave/(r)estore as argument.\n"));
+		  exit(0);
+	  }
   }
   
   /* If no task? - start applet */
@@ -327,7 +342,7 @@ void main_one(int argc, char **argv,int applet)
 	
 	  make_container();
 	
-	  gpe_set_window_icon(self.w,"icon");
+	  gpe_set_window_icon(self.w, "icon");
 	  gtk_widget_show_all(self.w);
 	 
 	  gtk_widget_show(self.w);
@@ -410,7 +425,10 @@ int main(int argc, char **argv)
 	  for( i = 0 ; i < applets_nb ; i++)
 	    {
           if (strcmp(argv[1], applets[i].name) == 0)
-          main_one(argc,argv,i);
+		  {
+          	main_one(argc, argv, i);
+			break;
+		  }
 	    }
 	  if (i == applets_nb)
 	    {
