@@ -409,7 +409,7 @@ network_create_widgets (void)
 	char *tmp = NULL;
 	struct interface *ife;
 	struct interface *int_list;
-	GtkWidget *table, *tw, *sw;
+	GtkWidget *table, *tw, *sw, *vp;
 	char *ts, *nwshort, *nwlong;
 	int pos = 0;
 
@@ -418,12 +418,17 @@ network_create_widgets (void)
 	sw = gtk_scrolled_window_new(NULL,NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 		GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw), 
+	                                    GTK_SHADOW_NONE);
 	
 	table = gtk_table_new(6,2,FALSE);
 	gtk_table_set_row_spacings(GTK_TABLE(table),gpe_get_boxspacing());
 	gtk_table_set_col_spacings(GTK_TABLE(table),gpe_get_boxspacing());
 	gtk_container_set_border_width(GTK_CONTAINER(table),gpe_get_border());
-	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW(sw),table);
+	vp = gtk_viewport_new(NULL, NULL);
+	gtk_viewport_set_shadow_type(GTK_VIEWPORT(vp), GTK_SHADOW_NONE);
+	gtk_container_add(GTK_CONTAINER(vp), table);
+	gtk_container_add(GTK_CONTAINER(sw),vp);
 	
 	tw = gtk_label_new(NULL);
 	ts = g_strdup_printf("<b>%s</b>",_("Network Status"));
@@ -450,7 +455,15 @@ network_create_widgets (void)
 
 			/* create widgets */
 			if (device_is_wlan(ife->name))
+			{
+				gchar *p = strstr(nwshort,"Ethernet");
+				if (p)
+				{
+					sprintf(p,_("Wireless"));
+					p[strlen(_("Wireless"))] = '\n';
+				}
 				tw = gtk_image_new_from_file(PIC_WLAN); 
+			}
 			else
 				tw = gtk_image_new_from_file(PIC_NET);
 			gtk_misc_set_alignment(GTK_MISC(tw),0.0,0.0);
